@@ -5,6 +5,9 @@ from pyallied.web.print_page_options import PrintOptions
 from pyallied.web.webWaits import customwebDriverwait
 from pyallied.web.log_type import log_type
 from pyallied.web.file_detector import FileDetector
+import os
+import base64
+from PIL import Image
 from selenium.webdriver.remote.file_detector import UselessFileDetector
 class Browser(customwebDriverwait):
     def __init__(self,driver):
@@ -108,60 +111,6 @@ class Browser(customwebDriverwait):
     kwargs - Keyword arguments, passed the same way as args.    
     '''  
     #def File_Detector_Context(self,file_detector_class, *args, **kwargs):
-
-
-    '''
-        Gets the full document screenshot of the current window as a base64 encoded string
-        which is useful in embedded images in HTML.
-
-        Usage:	
-        driver.get_full_page_screenshot_as_base64()
-    '''
-    def get_screenshot_ofcurrentActive_page_in_base64(self):
-        try:
-            return self.driver.get_full_page_screenshot_as_base64()
-        except Exception as error:
-            raise error    
-
-    '''
-        Saves a full document screenshot of the current window to a PNG image file. Returns
-        False if there is any IOError, else returns True. Use full paths in your filename.
-        Args:	
-        filename: The full path you wish to save your screenshot to. This should end with a .png extension.
-        Usage:	
-        driver.get_full_page_screenshot_as_file('/Screenshots/foo.png')
-    '''
-    def get_screenshot_ofcurrentActive_page_asFile(self,filename:str):
-        try:
-            return self.driver.get_full_page_screenshot_as_file(filename) 
-        except Exception as error:
-            raise error       
-    '''get_full_page_screenshot_as_png() → str
-        Gets the full document screenshot of the current window as a binary data.
-
-        Usage:	
-        driver.get_full_page_screenshot_as_png()
-    '''
-    def get_screenshot_ofcurrentActive_page_asPNG(self):
-        try:
-            return self.driver.get_full_page_screenshot_as_png()
-        except Exception as error:
-            raise error    
-
-    ''' 
-        Saves a screenshot of the current window to a PNG image file. Returns
-        False if there is any IOError, else returns True. Use full paths in your filename.
-        Args:	
-        filename: The full path you wish to save your screenshot to. This should end with a .png extension.
-        Usage:	
-        driver.save_screenshot('/Screenshots/foo.png')
-    '''
-    def screenshot_save_full_page_screenshot(self,filename):
-        try:
-            return self.driver.save_screenshot(filename)
-        except Exception as error:
-            raise error    
-
        
     '''
     Goes one step forward in the browser history.
@@ -414,7 +363,7 @@ class Browser(customwebDriverwait):
             raise error
     def Get_Page_Source(self):
         try:
-            return self.driver.page_source()
+            return self.driver.page_source
         except Exception as error:
             raise error
     def get_command_line_args(self):
@@ -457,4 +406,46 @@ class Browser(customwebDriverwait):
         try:
             return self.driver.service.service_url
         except Exception as error:
-            raise error                                                                                                               
\ No newline at end of file
+            raise error 
+    def get_driver_name(self):
+        try:
+            return self.driver.name
+        except Exception as error:
+            raise error
+    def get_orientation(self):
+        try:
+            return self.driver.orientation
+        except Exception as error:
+            raise error
+    def get_timeouts(self):
+        try:
+            return self.driver.timeouts
+        except Exception as error:
+            raise error
+    def get_screenshot_base64(self,name): 
+        try:
+            with open(self.__Screenshot_Location()+"/"+name+".jpg", "wb") as fh:
+                fh.write(base64.urlsafe_b64decode(self.driver.get_screenshot_as_base64()))            
+            
+        except Exception as error:
+            raise error
+    def get_screenshot_png(self,name): 
+        try:
+            with open(self.__Screenshot_Location()+"/"+name+".png", "wb") as fh:
+                fh.write(self.driver.get_screenshot_as_png())            
+            
+        except Exception as error:
+            raise error
+    def get_screenshot_file(self,name): 
+        try:
+            self.driver.get_screenshot_as_file(self.__Screenshot_Location()+"/"+name+'.png')
+            
+        except Exception as error:
+            raise error                        
+    def __Screenshot_Location(self):
+        try:
+            dir_name=os.getcwd()+"/page_Screenshots"
+            os.makedirs(dir_name, exist_ok=True)
+            return dir_name
+        except FileExistsError:
+            pass                                                                                                                                                                               
\ No newline at end of file
